// ----------------------------------------------------------------------------------
//
// roboFish.c                                                  Ulrich Mller 17.02.06
//                                                             PCS1700 Renesas C 4.00
// Betriebs-Routinen auf Basis der TransferArea
//
// ----------------------------------------------------------------------------------

#include "roboFish.h";

void InitFish(void) {                              // --- Initialisierung
	sTrans.MPWM_Update = 0x01;                       // --- Update PWM alle 10 ms
}

BOOL GetInput(UCHAR InputNr) {         // --- Abfrage I-Eingang
  return sTrans.E16_Main[--InputNr] ? TRUE : FALSE;
}
UCHAR GetInputs(void) {
  return sTrans.E_Main;
}

UINT GetAnalog(UCHAR AnalogNr) {
  switch(--AnalogNr) {
	  case 0: return sTrans.AX; break;
		case 1: return sTrans.AY; break;
		default: return 0;
	}
}

UINT GetVoltage(UCHAR VoltNr) {
  switch(--VoltNr) {
	  case 0: return sTrans.A1; break;
		case 1: return sTrans.A2; break;
		default: return 0;
	}
}

BOOL GetIRKey(UCHAR Code, UCHAR KeyNr) {
  KeyNr--;
	switch(Code) {
	  case 0:   // --- unabhngig vom Code
			return sTrans.IRKeys16[KeyNr] ? TRUE : FALSE;
			break;
		case 1: // --- Empnger 1
			return sTrans.IRKeys16Code1[KeyNr] ? TRUE : FALSE;
			break;
		case 2:  // --- Empfnger 2
			return sTrans.IRKeys16Code2[KeyNr] ? TRUE : FALSE;
			break;
		default :
			return FALSE;
			break;
  }
}

void SetMotor(UCHAR MotorNr, UCHAR Dir, UCHAR Speed) {  // --- Schalten MotorAusgang mit var. Speed
 	UCHAR n = --MotorNr << 1;
  Speed--;
  sTrans.M_Main &= ~(3 << n);      // --- Richtung lschen
  switch (Dir) {                   //              setzen
    case 0: break;
	  case 1:                        // --- Links
			sTrans.M_Main |= 1 << n;
			sTrans.MPWM_Main[n] = Speed;  
			break; 
	  case 2:                        // --- Rechts
		  sTrans.M_Main |= 2 << n; 
			sTrans.MPWM_Main[n+1] = Speed;  
			break;
  }
}

UCHAR GetMotors(void) {
	return sTrans.M_Main;
}

void SetMotors(UCHAR MotorStatus, UINT SpeedStatus) {
  UCHAR i, i2, i21;
	UCHAR Speed;
	sTrans.M_Main = MotorStatus;
  for(i = 0; i < 4; i++) {
		i2  = i * 2;
		i21 = i2 + 1;
		Speed = (SpeedStatus & (0x0F << (i*4))) >> (i*4);
		sTrans.MPWM_Main[i2]  = Speed;
		sTrans.MPWM_Main[i21] = Speed;
	}
}

void SetLamp(UCHAR LampNr, BOOL OnOff, UCHAR Power) {
	UINT n = --LampNr % 8;
	if(OnOff) sTrans.M_Main |= 1 << n;
	else sTrans.M_Main &= ~(1 << n);
	sTrans.MPWM_Main[n] = --Power;
}

void WaitForChange(UCHAR InputNr, UINT NrOfChanges, UCHAR TermNr) { // --- Warten auf Anzahl Impulse
  UINT INew, IOld;
  InputNr--;
	TermNr--;
  IOld = sTrans.E16_Main[InputNr];                   // --- Merken Ausgangsstand des Eingangs
  do {
	  if(TermNr < 8 & sTrans.E16_Main[TermNr]) return;
    INew = sTrans.E16_Main[InputNr];                 // --- Feststellen aktueller Stand
	if(INew != IOld) { IOld = INew; NrOfChanges--;}    // --- Abfrage auf Vernderung
  } while(NrOfChanges);                              // --- Loopende, wenn NrOfChanges = 0
}
void WaitForInput(UCHAR InputNr, BOOL OnOff) {
	while(GetInput(InputNr) != OnOff);
}
